#
# spec file for package gnome-weather
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define full_name org.gnome.Weather
Name:           gnome-weather
Version:        47.0
Release:        1.3
Summary:        Weather App for GNOME
License:        GPL-2.0-or-later
Group:          Productivity/Other
URL:            https://apps.gnome.org/app/org.gnome.Weather
Source0:        %{name}-%{version}.tar.zst

# PATCH-FIX-UPSTREAM gnome-weather-BackgroundService-service-fails-to-start.patch bsc#1209391 glgo#GNOME/gnome-weather!132 xwang@suse.com -- org.gnome.Weather.BackgroundService fails to start
Patch0:         gnome-weather-BackgroundService-service-fails-to-start.patch

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  intltool >= 0.26
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gjs-1.0) >= 1.71.0
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.35.9
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(gweather4)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.4.alpha
BuildRequires:  pkgconfig(libgeoclue-2.0) >= 2.3.1
BuildArch:      noarch

%description
GNOME 3 weather app that does:

  * Display current conditions;
  * Display forecasts;
  * Show radar maps;
  * Notify on hazardous weather conditions.

%package -n gnome-shell-search-provider-gnome-weather
Summary:        GNOME Weather -- Search Provider for GNOME Shell
Group:          Productivity/Other
Requires:       %{name} = %{version}
Supplements:    (gnome-shell and %{name})

%description -n gnome-shell-search-provider-gnome-weather
This package contains a search provider to enable GNOME Shell to get
search results from GNOME Weather.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	--libdir=%{_prefix}/unused-in-noarch \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{full_name} %{?no_lang_C} %{name}.lang

%check
%meson_test

%files
%license COPYING.md
%doc NEWS README.md
%{_bindir}/%{name}
%{_datadir}/metainfo/org.gnome.Weather.appdata.xml
%{_datadir}/applications/org.gnome.Weather.desktop
%{_datadir}/%{full_name}/
%{_datadir}/dbus-1/services/org.gnome.Weather.service
%{_datadir}/dbus-1/services/org.gnome.Weather.BackgroundService.service
%{_datadir}/glib-2.0/schemas/org.gnome.Weather.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{full_name}*
%{_datadir}/icons/hicolor/scalable/status/*

%files -n gnome-shell-search-provider-gnome-weather
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.Weather.search-provider.ini

%files lang -f %{name}.lang

%changelog
* Wed Sep 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Switch to source service for tarball.
* Mon Sep 16 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Use AdwSpinner for loading page
  + Updated translations.
* Tue Sep 10 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.alpha:
  + Use adaptive dialogs
  + Add tooltip to Main Menu
  + Miscellaneous style cleanups
  + Updated translations.
* Fri Mar 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Incorrect/missing URLs in app metadata.
  + Updated translations.
* Mon Sep 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + The "Feels Like" temperature label is now hidden when it
    matches the actual temperature.
  + By default the window is now large enough to see the
    thermometer widgets in the Daily view.
  + Updated translations.
* Fri Jul  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + The "Feels Like" temperature label is now hidden when it
    matches the actual temperature
  + By default the window is now large enough to see the
    thermometer widgets in the Daily view
  + Updated translations.
* Fri Mar 31 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add gnome-weather-BackgroundService-service-fails-to-start.patch:
  org.gnome.Weather.BackgroundService fails to start
  (bsc#1209391 glgo#GNOME/gnome-weather!132).
* Sun Mar 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Weather 44.0 comes with a slight UI refresh, featuring flat
    headers that give the app a unified look, and a smooth
    temperature graph.
  + Updated translations.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Updated translations.
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Slight UI referesh, featuring flat headers that give the app a
    unified look.
  + The temperature graph now uses a smooth line instead of jagged
    lines.
  + Updated translations.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + The thermometer widget in the daily view has received a round
    of polish, with temperature labels sticking to the thermometer
    as it scales.
  + The temperature choice in the primary menu is now at the top
    level.
  + Views now transitions smoothly with a crossfade.
  + We use a new adaptive About window.
  + Updated translations.
* Sun Sep  4 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 43.rc:
  + Updated translations.
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Updated translations.
* Mon Jul 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + GNOME Weather 43.alpha polishes the thermometer widget in the
    daily view, refreshes the primary menu, uses smooth transitions
    between views, and makes use of a new adaptive About window.
  + Updated translations.
* Mon Mar 21 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 42.0:
  + New thermometer widget.
  + Updated translations.
- Update https://live.gnome.org/Design/Apps/Weather URL tag to
  https://apps.gnome.org/app/org.gnome.Weather new GNOME Weather's
  web home.
* Tue Mar  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Fix position of "Now" in hourly forecast.
  + Updated translations.
* Wed Feb 16 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Port to GTK4 and libadwaita
  + Updated translations.
- Replace the following BuildRequires:
  + pkgconfig(gtk+-3.0) with pkgconfig(gtk4)
  + pkgconfig(gweather-3.0) with pkgconfig(gweather4)
  + pkgconfig(libhandy-1) with pkgconfig(libadwaita-1)
- Drop 4be71525f07189e97720688472172604879d49a5.patch: Fixed
  upstream.
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 4be71525f07189e97720688472172604879d49a5.patch: Fix build
  with meson 0.61 and newer.
- Drop update-desktop-files BuildRequires and macro, no longer
  needed.
- Add appstream-glib and desktop-file-utils BuildRequires, verify
  desktop file and metainfo during meson_test macro run.
* Wed Jan 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha:
  + Show current temperature in the forecast chart.
  + Opt in to libhandy dark style preference.
  + Add new Thermometer widget.
  + Use location portal to access location.
  + Fix hourly graph shifted to the left by one day.
  + Updated translations.
* Tue Sep 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Updated translations.
* Wed Aug 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.1:
  + Add corner radius to forecast chart.
  + Increase contrast when using dark themes.
  + Bugs fixed: glgo#GNOME/gnome-weather#146,
    glgo#GNOME/gnome-weather#168, glgo#GNOME/gnome-weather#190,
    glgo#GNOME/gnome-weather!82, glgo#GNOME/gnome-weather#169.
  + Updated translations.
- Drop patches fixed upstream:
  + gnome-weather-wrong-min-temperature.patch
  + gnome-weather-welcome-screen-when-saved-locations.patch
  + gnome-weather-fix-forever-loading.patch
* Sat Jul 24 2021 Atri Bhattacharya <badshah400@gmail.com>
- Add patches to fix multiple issues:
  + gnome-weather-wrong-min-temperature.patch: Fix daily forecast
    showing incorrect daily low temperature
    (glgo#GNOME/gnome-weather#190).
  + gnome-weather-welcome-screen-when-saved-locations.patch: Do
    not show the initial welcome/search screen when loading the
    previously saved locations (glgo#GNOME/gnome-weather#169).
  + gnome-weather-fix-forever-loading.patch Fix loading forever
    with error message "TypeError: location.get_timezone(...) is
    null" when automatic location is turned off
    (glgo#GNOME/gnome-weather#127).
* Sun Mar 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + Major redesign with new charts.
  + Adaptive for mobile and desktop.
  + Updated translations.
* Sat Jan 16 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Major redesign with new charts.
  + Adaptive for mobile and desktop.
  + Bugs fixed: Unknown temperature and cloud conditions since
    3.34.1 when using auto location.
  + Updated translations.
- Add pkgconfig(libhandy-1) BuildRequires: new dependency.
* Fri Apr 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Bugs fixed: Unknown temperature and cloud conditions when using
    autolocation.
- Enable testsuite: Add check section and run meson_test macro.
* Fri Apr 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Bugs fixed:
  - Always shows weather for wrong location.
  - Deduplicate cities in locations popover.
  + Bugs introduced: Unknown location since 3.34.1 (sorry!).
  + New nightly app icon.
  + Publish nightlies from CI.
  + Added README.
  + Updated translations.
* Fri Apr 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Bugs fixed: Unknown temperature and cloud conditions when using
    autolocation.
* Fri Apr  3 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Bugs fixed: Always shows weather for wrong location.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Nov  6 2019 Michael Gorse <mgorse@suse.com>
- Stop using arch-specific libdir again (boo#1109687).
* Wed Sep 25 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + tests: Make dogtail tests optional.
  + Updated translations.
* Thu Sep  5 2019 Chingkai Chu <qkzhu@suse.com>
- Update to version 3.33.90:
  + Export location information to GNOME Shell.
  + Use weather station's time zone.
  + Allow enter key to show location.
  + Bugs fixed: !18 Fix search provider
  + Updated translations.
* Mon Apr 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Bugs fixed: Logged warning about non-standard use of
    `array.toString() on a Uint8Array instance`.
  + Updated translations.
* Fri Apr  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Bugs fixed: The app is not translated.
  + Updated translations.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Migrate app menu to primary menu.
  + New icon.
  + Show tomorrow's forecasts at the end of the day.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Bugs fixed: 3.31.90 no longer installs a binary in the path.
  + Updated translations.
* Sun Feb 17 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Port from Autotools to Meson.
  + Show tomorrow's forecasts at the end of the day.
  + Unify App ID.
  + Updated translations.
- Add meson BuildRequires and macros following upstreams port to
  meson buildsystem.
* Mon Feb  4 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Stop using arch-specific libdir (boo#1109687)
* Fri Jan  4 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Migrate app menu to primary menu.
  + New icon.
  + Update GJS dependency.
  + Updated translations.
- Drop upstream fixed patches:
  + gnome-weather-fix-gettext-domain.patch.
  + gnome-weather-fix-clicking-rows-places-popover.patch.
- Drop unneeded gjs BuildRequires, we have the pkgconfig variant
  already.
- Drop glib2_gsettings_schema_requires, no longer needed.
* Sat Mar 17 2018 bjorn.lie@gmail.com
- Add gnome-weather-fix-clicking-rows-places-popover.patch: Fix
  clicking on rows in the places popover. With recent gjs, the
  access to row._info fails after the row has been removed from the
  listbox.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Dec  2 2017 zaitor@opensuse.org
- Add gnome-weather-fix-gettext-domain.patch: gschema: Fix
  gettext-domain.
- Drop post(un) handling of glib2_gsettings_schema_post(un),
  desktop_database_post(un) and icon_theme_cache_post(un), we have
  file-triggers taking care of this now.
- Modernize spec, run spec-cleaner, use autosetup and make_build
  macros.
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 3.25.92:
  + Updated translations.
* Sun Aug 20 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Weather can now be tiled on sufficiently large monitors
    (bgo#725407).
  + Fixed compatibility with mozjs52, and improved code to take
    advantage of the new JavaScript features.
  + Updated translations.
* Mon Mar 20 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Updates for the new version of gjs (bgo#778641).
  + Improvements to the build system for GNOME Builder.
  + Updated translations.
- Drop gnome-weather-work-with-new-gjs.patch: Fixed upstream.
* Mon Feb 27 2017 zaitor@opensuse.org
- Add gnome-weather-work-with-new-gjs.patch: No longer crash on
  launch when using gjs 1.48 or newer (bgo#778641).
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Minor bug fixes.
  + Updated translations.
* Fri May 27 2016 idonmez@suse.com
- Update to GNOME 3.20.2 FATE#318572
* Mon May  9 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Build system fixes.
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Updated translations.
* Tue Feb 16 2016 dimstar@opensuse.org
- Update to version 3.19.90:
  + Fix missing items in forecast (bgo#757186).
  + Add support for Geoclue agent dialog (bgo#762102).
  + Add missing tags to Appdata.
  + Build system updates and xdg-app support.
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.1:
  + Convert from DBus API to libgeoclue (bgo#756647).
- Add pkgconfig(libgeoclue-2.0) BuildRequires: New dependency
  following upstreams convert.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Sat Sep 12 2015 zaitor@opensuse.org
- Update to version 3.17.92:
  + Improved background for licensing and legibility (bgo#703150,
    bgo#754892).
  + Updated translations.
* Tue Jul 28 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Fix initial application state when geolocation is disabled.
  + Fix temperature unit shown in the menu when not explicitly
    configured.
  + Updated translations.
* Mon Apr 27 2015 zaitor@opensuse.org
- Update to version 3.16.2.1:
  + Provide a symbolic variant of the app icon (bgo#747189).
* Mon Apr 27 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Honor 12/24 time format in city view (bgo#741533).
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Fixed the missing attribution to the weather data sources in
    the About dialog.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Launching search from the overview (clicking on the weather
    icon next to results) is now supported.
  + The weekly forecast sidebar now includes tomorrow and uses
    2pm as the representative forecast (bgo#741532).
  + Misc bug fixes to the search provider and to the world popup.
  + Build system fixes (bgo#745581).
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Build system fixes (bgo#740414).
  + Fixed opening the app on a specific location (eg when launched
    from gnome-maps) (bgo#740414).
  + Fixed showing the world popover on a second window
    (bgo#740414).
  + Updated translations.
* Mon Feb 16 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Fix history handling (bgo#741837).
  + Fixed crash when Geoclue is not available (bgo#742460).
  + Improved the forecast for the current location.
  + Updated translations.
* Thu Jan 29 2015 zaitor@opensuse.org
- Update to version 3.15.1:
  + Added keywords to the desktop file.
  + Updated translations.
* Mon Oct 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Fixed compatibility with gtk+ 3.14 (bgo#737818).
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Added high contrast icon (bgo#707286).
  + Updated translations.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Completely redesign the application (bgo#733236).
  + Remove libgd submodule and make the application noarch.
  + Disable the search provider by default (bgo#734048).
  + Updated translations.
- Change BuildArch to noarch, following upstreams advise.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + We now use package.js from gjs upstream.
  + Fixed search-provider (bgo#732344).
  + Misc fixes.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Updates to the appstream metadata, and new screenshots
    (requires a new version of libappstream-glib, or building
    with --disable-appstream-util).
  + Various miscellaneous fixes and updates.
  + Updated translations.
- Changes from version 3.13.2:
  + Appdata metadata was updated to the new specification.
  + The installation folder for the application was renamed to
    $(datadir)/org.gnome.Weather, removing the final .Application
    part.
  + The search provider was split into a background service, to
    avoid triggering geolocation without the user consent (only the
    frontend application does it now).
- Changes from version 3.13.1:
  + Show local time in city view (bgo#705050).
  + Add geolocation support (automatically add the current location
    to the world view) (bgo#704268).
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Fix alignment of placeholder text for first run (bgo#721732).
  + Build fixes (bgo#725942).
  + Updated translations.
* Tue Mar  4 2014 dimstar@opensuse.org
- Update to version 3.11.91:
  + Fix problem loading the app without network connectivity.
  + Fix running tests with a11y disabled (bgo#725152).
  + Fix running tests against old pygobject+glib (bgo#725398).
  + Fix automake requirement (bgo#725427).
  + Updated translations.
* Wed Feb 19 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Fixed a crash at shutdown, caused by a destroy vfunc.
  + Added coverage reports for tests.
  + Updated for unstable GTK+ API changes (GtkActionBox).
  + Fixed the sensitivity of Add in new location dialog
    (bgo#724416).
  + Once again, changes to the build and deployment infrastructure.
  + Updated translations.
* Mon Feb  3 2014 zaitor@opensuse.org
- Update to version 3.11.5:
  + JS sources are now loaded from a GResource, which should
    improve startup times as it requires fewer seeks on disk.
  + All dialogs were converted to use a header bar.
  + A new infrastructure for application tests exists, and
    minimal automated testing for the world view is included.
  + Updated translations.
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Fixes for RTL layouts (bgo#721123).
  + Updates to the packaging system.
  + Added the ability to build an RPM from the upstream tarball.
  + Replaced GtkHeaderBar with GtkActionBar (and gtk+ dependency
    raised).
  + Fixed the .desktop file for legacy environments (not using GIO
    to launch the application).
  + Updated translations.
* Wed Dec 18 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Always show a title in the header bar (bgo#720322).
  + CityView is now consistent with other apps wrt the back button
    (bgo#720321).
  + We now follow the HIGs for standard items in the app menu.
  + The sidebar can show forecast for today and tomorrow at all
    times.
  + We no longer show the night before the day, which was reported
    as confusing.
  + Updated translations.
- Create new subpackage gnome-shell-search-provider-gnome-weather,
  containing the GNOME Shell search provider.
* Tue Oct 15 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 firebird209@gmail.com
- Update to version 3.9.92:
  + Delay showing the window until the view is fully loaded.
  + Make use of the spinner next to the app menu when refreshing
    the forecasts.
  + Updated translations.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Further update the UI to match the selection mode mockups.
  + Add an AppData file to be used by gnome-software.
  + Add a shell search provider to show weather for configured
    locations.
  + Updated translations.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + All publicly visible IDs for the application (including the
    .desktop file name and installation folder) now follow the
    reverse DNS notation convention, that is, they are
    "org.gnome.Weather.Application".
  + The application is now DBus activated, and only ships a shim
    launcher in $bindir.
  + In city view, the side bar is now overlaid on the rest of the
    content rather than pushing it.
  + We use now GTK+ support for the close button in the header.
  + Updated translations.
* Thu Aug 15 2013 dimstar@opensuse.org
- Do not package *.la files (even in private libdir).
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 3.9.5:
  + Fixed selection mode to latest mockups.
  + Enabled OpenWeatherMap backend.
  + Updated for libgweather API changes.
  + Updated translations.
- Add new BuildRequires, as verified by configure:
  + pkgconfig(gdk-3.0), pkgconfig(glib-2.0),
    pkgconfig(gobject-2.0), pkgconfig(gweather-3.0).
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Fixed icon handling in GWeatherLocationEntry due to the ABI
    change in libgweather.
  + Replaced most of libgd with Gtk types (still using GdMainView
    only).
  + Now using the header bar as a titlebar (fixes the close button
    when maximized).
  + Includes a new application icon, designed specifically for
    gnome-weather.
  + Once again fixed launching the application in certain
    "looks-like-source-tree" cases.
  + Updated translations.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 3.9.2:
  + Updated libgd, but mostly replaced with Gtk types.
  + Added a welcome screen for the first launch.
  + The app menu now offers a choice for the temperature unit.
  + Implements the new selection pattern, with a separate selection
    toolbar and rubberbanding.
  + Improved the libgweather usage to support disk caching.
* Mon May 13 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Update libgd to master.
  + Fix detection of source trees at startup.
  + Updated translations.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Update libgd to master.
  + Updated translations.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + First release to follow GNOME versioning.
  + Application completely rewritten in JS + gtk + libgd.
  + Features a full GNOME 3 layout (header bar, content view,
    selection toolbar, application menu).
  + Includes the ability to show multiple cities at once.
  + Uses dark theme and symbolic icons.
  + Includes pretty backgrounds matching the current conditions.
  + Many many bugfixes and translation fixes.
- Replace python BuildRequires with gjs, following upstreams port
  to JavaScript.
- Drop pkgconfig(clutter-1.0) and pkgconfig(gweather-3.0)
  BuildRequires: no longer needed.
- Add glib2_gsettings_schema and desktop_database macros to post
  and postun.
* Wed Mar  6 2013 dimstar@opensuse.org
- Initial package, version 0.2.
